; <?php return; ?> DO NOT DELETE THIS LINE
dbtype="mysql"
dbhost="[[softdbhost]]"
dbport="3306"
dbuser="[[softdbuser]]"
dbpass="[[softdbpass]]"
dbname="[[softdb]]"
tblpfx="[[dbprefix]]"
base_url="[[softurl]]"
rewrite_urls="0"
